@@ -134,7 +134,14 @@ class TTRClient(object):
         :param include_nested: *Optional* Include child categories. Default
             is ``False``.
         """
-        r = self._get_json({'op': 'getFeeds', 'cat_id': cat_id})
+        r = self._get_json({
+            'op': 'getFeeds',
+            'cat_id': cat_id,
+            'unread_only': unread_only,
+            'limit': limit,
+            'offset': offset,
+            'include_nested': include_nested
+        })
         return [Feed(feed, self) for feed in r['content']]
 
     def get_headlines(
@@ -191,8 +198,11 @@ class TTRClient(object):
         """
         Get a list of articles from article ids.
 
-        :param article_id: A comma separated string of article ids to fetch.
+        :param article_id: A comma separated string or list of article ids to
+            fetch,
         """
+        if isinstance(article_id, list):
+            article_id = ",".join([str(i) for i in article_id])
         r = self._get_json({'op': 'getArticle', 'article_id': article_id})
         return [Article(article, self) for article in r['content']]
 
@@ -228,8 +238,11 @@ class TTRClient(object):
         """
         Mark an article as unread.
 
-        :param article_id: ID of article to mark as unread.
+        :param article_id: List or comma separated string of IDs of articles
+            to mark as unread.
         """
+        if isinstance(article_id, list):
+            article_id = ",".join([str(i) for i in article_id])
         r = self._get_json({
             'op': 'updateArticle',
             'article_ids': article_id,
@@ -241,8 +254,11 @@ class TTRClient(object):
         """
         Mark an article as read.
 
-        :param article_id: ID of article to mark as read.
+        :param article_id: List or comma separated string of IDs of articles
+            to mark as read.
         """
+        if isinstance(article_id, list):
+            article_id = ",".join([str(i) for i in article_id])
         r = self._get_json({
             'op': 'updateArticle',
             'article_ids': article_id,
@@ -255,8 +271,11 @@ class TTRClient(object):
         """
         Toggle the unread status of an article.
 
-        :param article_id: ID of the article to toggle.
+        :param article_id: List or comma separated string of IDs of articles
+            to toggle unread.
         """
+        if isinstance(article_id, list):
+            article_id = ",".join([str(i) for i in article_id])
         r = self._get_json({
             'op': 'updateArticle',
             'article_ids': article_id,
@@ -277,6 +296,41 @@ class TTRClient(object):
             'is_cat': is_cat
         })
 
+    def get_feed_count(self):
+        """Return total number of feeds"""
+        r = self._get_json({'op': 'getConfig'})
+        return int(r['content']['num_feeds'])
+
+    def update_daemon_running(self):
+        """Return ``True`` if update daemon is running, ``False`` otherwise."""
+        r = self._get_json({'op': 'getConfig'})
+        return r['content']['daemon_is_running']
+
+    def subscribe(self, feed_url, category_id=0, login=None, password=None):
+        """Subscribe to specified feed.
+
+        :param feed_url: URL to the feed to subscribe to.
+        :param category_id: Place feed in the category with this ID.
+        :param login: Login name for the feed, if any.
+        :param password: Password for the feed, if any.
+        """
+
+        r = self._get_json({
+            'op': 'subscribeToFeed',
+            'feed_url': feed_url,
+            'category_id': category_id,
+            'login': login,
+            'password': password
+        })
+
+    def unsubscribe(self, feed_id):
+        """Unsubscribe to specified feed
+
+        :param feed_id: ID of feed to unsubscribe.
+        """
+
+        r = self._get_json({'op': 'unsubscribeFeed', 'feed_id': feed_id})
+
 
 class RemoteObject(object):
     """
